from groundx.paths.v1_project_project_id.get import ApiForget
from groundx.paths.v1_project_project_id.put import ApiForput
from groundx.paths.v1_project_project_id.delete import ApiFordelete


class V1ProjectProjectId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass
